@@ -212,6 +212,11 @@ int argc;
      */
     SetNoteDir();
 
+    /*
+     * Construct the path to the temporary directory ...
+     */
+    SetTempDir();
+
     /*
      * Create the plaid, menu, and list widgets.
      */
